==> sm2cipher-0.0.1.tar.gz: lib/src/sm2Curve.dart <==
// See file LICENSE for more information.

library impl.ec_domain_parameters.secp256k1;

import 'package:pointycastle/ecc/api.dart';
import 'package:pointycastle/ecc/ecc_base.dart';
import 'package:pointycastle/src/ec_standard_curve_constructor.dart';
import 'package:pointycastle/src/registry/registry.dart';

// ignore: camel_case_types
class ECCurve_sm2 extends ECDomainParametersImpl {
  static final FactoryConfig factoryConfig =
      StaticFactoryConfig(ECDomainParameters, 'sm2', () => ECCurve_sm2());

  factory ECCurve_sm2() => constructFpStandardCurve('sm2', ECCurve_sm2._make,
      q: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF',
          radix: 16),
      a: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFC',
          radix: 16),
      b: BigInt.parse(
          '28E9FA9E9D9F5E344D5A9E4BCF6509A7F39789F515AB8F92DDBCBD414D940E93',
          radix: 16),
      g: BigInt.parse(
          '0432C4AE2C1F1981195F9904466A39C9948FE30BBFF2660BE1715A4589334C74C7BC3736A2F4F6779C59BDCEE36B692153D0A9877CC62A474002DF32E52139F0A0',
          radix: 16),
      n: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF7203DF6B21C6052B53BBF40939D54123',
          radix: 16),
      h: BigInt.parse('1', radix: 16),
      seed: null) as ECCurve_sm2;

  static ECCurve_sm2 _make(String domainName, ECCurve curve, ECPoint G,
          BigInt n, BigInt _h, List<int> seed) =>
      ECCurve_sm2._super(domainName, curve, G, n, _h, seed);

  ECCurve_sm2._super(String domainName, ECCurve curve, ECPoint G, BigInt n,
      BigInt _h, List<int> seed)
      : super(domainName, curve, G, n, _h, seed);
}

==> sm2cipher-0.0.7.tar.gz: lib/src/sm2Curve.dart <==
// See file LICENSE for more information.

library impl.ec_domain_parameters.secp256k1;

import 'package:pointycastle/ecc/api.dart';
import 'package:pointycastle/ecc/ecc_base.dart';
import 'package:pointycastle/src/ec_standard_curve_constructor.dart';
import 'package:pointycastle/src/registry/registry.dart';

// ignore: camel_case_types
class ECCurve_sm2 extends ECDomainParametersImpl {
  static final FactoryConfig factoryConfig =
      StaticFactoryConfig(ECDomainParameters, 'sm2', () => ECCurve_sm2());

  factory ECCurve_sm2() => constructFpStandardCurve('sm2', ECCurve_sm2._make,
      q: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF',
          radix: 16),
      a: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFC',
          radix: 16),
      b: BigInt.parse(
          '28E9FA9E9D9F5E344D5A9E4BCF6509A7F39789F515AB8F92DDBCBD414D940E93',
          radix: 16),
      g: BigInt.parse(
          '0432C4AE2C1F1981195F9904466A39C9948FE30BBFF2660BE1715A4589334C74C7BC3736A2F4F6779C59BDCEE36B692153D0A9877CC62A474002DF32E52139F0A0',
          radix: 16),
      n: BigInt.parse(
          'FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF7203DF6B21C6052B53BBF40939D54123',
          radix: 16),
      h: BigInt.parse('1', radix: 16),
      seed: null) as ECCurve_sm2;

  static ECCurve_sm2 _make(String domainName, ECCurve curve, ECPoint G,
          BigInt n, BigInt _h, List<int>? seed) =>
      ECCurve_sm2._super(domainName, curve, G, n, _h);

  ECCurve_sm2._super(
      String domainName, ECCurve curve, ECPoint G, BigInt n, BigInt _h)
      : super(domainName, curve, G, n, _h, null);
}
